//****************************************************************************
//
//  written by Michael Rudolph, UNIC/CNRS Paris, February 2002
//
//****************************************************************************

//----------------------------------------------------------------------------
//
//  INCLUDES
//
//----------------------------------------------------------------------------
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <time.h>
#include "XCellModel.h"
#include "calculateXCellResponse.c"


//----------------------------------------------------------------------------
//
//  GLOBALS and PREDECLARATIONS
//
//----------------------------------------------------------------------------

struct sSimulation Simulation;
struct sSwitchingGRP SwitchingGRP;
struct sVisualStimulus_bar Stimulus_bar;
struct sVisualStimulus_cspot Stimulus_cspot;
struct sStageOut A[9];
struct sStageOut B[9];
struct sStageOut C[9];
struct sStageOut FreqOut;
struct sStageOut SpikeOut;
struct sSpatialFilter SpatialFilter[9];
struct sTemporalFilter_phasic TemporalFilter_phasic[5];
struct sTemporalFilter_tonic TemporalFilter_tonic[5];
float SpontaneousActivity;
int Stimulus;
double Stimulus_start;
double Stimulus_end;

#define SMALL           1.0e-3
#define CSPOT_STIMULUS  1
#define BAR_STIMULUS    2


//----------------------------------------------------------------------------
//
//  INITIALIZATION PROCEDURE
//
//----------------------------------------------------------------------------

void initializeXCell() {
  int i, k;
  long seed;
  double t, ti, t1i, t2i;

  //-------------------------------------------------------[ Simulation ]-----
  time(&seed);
  //->Simulation.tstart = 0.0;
  //->Simulation.tend = 1500;
  //->Simulation.dt = 0.1;
  //->Simulation.Vrest = -70;
  //->Simulation.Vspike = 20;
  Simulation.seed = -seed;
  i = (int)((Simulation.tend-Simulation.tstart)/dt)+1;
  k = 1;
  while (k < i) k *= 2;
  Simulation.maxindex = k;

  //-----------------------------------------------------[ SwitchingGRP ]-----
  //->SwitchingGRP.Threshold = 65.0;
  //->SwitchingGRP.OrderGRP[1] = 1;
  //->SwitchingGRP.OrderGRP[2] = 5;
  SwitchingGRP.tres = Simulation.dt;
  SwitchingGRP.maxIndex_t_tau = Simulation.maxindex;
  SwitchingGRP.t_tau = calloc(SwitchingGRP.maxIndex_t_tau+1, sizeof(double));
  SwitchingGRP.t_tau[0] = 0.0;
  SwitchingGRP.NumberSwitches = 1;

  //-----------------------------------------------------[ Stimulus_bar ]-----
  //Stimulus = BAR_STIMULUS;
  //->Stimulus_bar.a = 0.5;
  //->Stimulus_bar.b = 2.0;
  //->Stimulus_bar.x0 = 0.0;
  //->Stimulus_bar.y0 = 0.5;
  //->Stimulus_bar.theta = 3.1415/1.0;
  Stimulus_bar.I = calloc (2*(Simulation.maxindex)+1, sizeof(float));
  Stimulus_bar.I[0] = 0.0;

  //---------------------------------------------------[ Stimulus_cspot ]-----
  //->Stimulus = CSPOT_STIMULUS;
  //->Stimulus_cspot.D = 0.5;
  Stimulus_cspot.I = calloc (2*(Simulation.maxindex)+1, sizeof(float));
  Stimulus_cspot.I[0] = 0.0;

  //----------------------------------------------------------------[ A ]-----
  for (i=1; i<=8; i++) {
    A[i].tres = Simulation.dt;
    A[i].out = calloc (2*(Simulation.maxindex)+1, sizeof(float));
    A[i].out[0] = 0.0;
  }

  //----------------------------------------------------------------[ B ]-----
  for (i=1; i<=8; i++) {
    B[i].tres = Simulation.dt;
    B[i].out = calloc (2*(Simulation.maxindex)+1, sizeof(float));
    B[i].out[0] = 0.0;
  }

  //----------------------------------------------------------------[ C ]-----
  for (i=1; i<=8; i++) {
    C[i].tres = Simulation.dt;
    C[i].out = calloc (2*(Simulation.maxindex)+1, sizeof(float));
    C[i].out[0] = 0.0;
  }

  //----------------------------------------------------------[ FreqOut ]-----
  FreqOut.tres = Simulation.dt;
  FreqOut.out = calloc (2*(Simulation.maxindex)+1, sizeof(float));
  FreqOut.out[0] = 0.0;

  //---------------------------------------------------------[ SpikeOut ]-----
  SpikeOut.tres = Simulation.dt;
  SpikeOut.out = calloc (2*(Simulation.maxindex)+1, sizeof(float));
  SpikeOut.out[0] = Simulation.Vrest;

  //----------------------------------------------------[ SpatialFilter ]-----
  //->SpatialFilter[1].sigma = 0.11;
  //->SpatialFilter[2].sigma = 0.33;
  //->SpatialFilter[3].sigma = 0.11;
  //->SpatialFilter[4].sigma = 0.33;
  //->SpatialFilter[5].sigma = 0.11;
  //->SpatialFilter[6].sigma = 0.33;
  //->SpatialFilter[7].sigma = 0.11;
  //->SpatialFilter[8].sigma = 0.33;

  //--------------------------------------------[ TemporalFilter_phasic ]-----
  //->TemporalFilter_phasic[1].A = 3370.0;
  //->TemporalFilter_phasic[1].tau1 = 13.0;
  //->TemporalFilter_phasic[1].tau2 = 15.0;

  //->TemporalFilter_phasic[2].A = 3370.0;
  //->TemporalFilter_phasic[2].tau1 = 13.0;
  //->TemporalFilter_phasic[2].tau2 = 15.0;

  //->TemporalFilter_phasic[3].A = 1900.0;
  //->TemporalFilter_phasic[3].tau1 = 13.0;
  //->TemporalFilter_phasic[3].tau2 = 15.0;

  //->TemporalFilter_phasic[4].A = 1900.0;
  //->TemporalFilter_phasic[4].tau1 = 13.0;
  //->TemporalFilter_phasic[4].tau2 = 15.0;

  for (k=1; k<=4; k++) {
    TemporalFilter_phasic[k].tres = Simulation.dt;
    TemporalFilter_phasic[k].h = calloc ((Simulation.maxindex)+1, sizeof(float));
    t1i = 1.0/TemporalFilter_phasic[k].tau1;
    t2i = 1.0/TemporalFilter_phasic[k].tau2;

    for (i=1; i<=(int)(((Simulation.maxindex)-1)/2); i++) {
      t = (i-1)*(TemporalFilter_phasic[k].tres);
      TemporalFilter_phasic[k].h[i] = TemporalFilter_phasic[k].A * ( t1i*exp(-t*t1i) - t2i*exp(-t*t2i) );
    }

    for (i=((int)(((Simulation.maxindex)-1)/2)+1); i<=Simulation.maxindex; i++) {
      TemporalFilter_phasic[k].h[i] = 0.0;
    }
  }

  //---------------------------------------------[ TemporalFilter_tonic ]-----
  //->TemporalFilter_tonic[1].B = 74.0;
  //->TemporalFilter_tonic[1].tau = 15.0;

  //->TemporalFilter_tonic[2].B = 74.0;
  //->TemporalFilter_tonic[2].tau = 15.0;

  //->TemporalFilter_tonic[3].B = 33.0;
  //->TemporalFilter_tonic[3].tau = 15.0;

  //->TemporalFilter_tonic[4].B = 33.0;
  //->TemporalFilter_tonic[4].tau = 15.0;

  for (k=1; k<=4; k++) {
    TemporalFilter_tonic[k].tres = Simulation.dt;
    TemporalFilter_tonic[k].h = calloc ((Simulation.maxindex)+1, sizeof(float));
    ti = 1.0/TemporalFilter_tonic[k].tau;

    for (i=1; i<=(int)(((Simulation.maxindex)-1)/2); i++) {
      t = (i-1)*TemporalFilter_tonic[k].tres;
      TemporalFilter_tonic[k].h[i] = TemporalFilter_tonic[k].B * ti * exp(-t*ti);
    }

    for (i=((int)(((Simulation.maxindex)-1)/2)+1); i<=Simulation.maxindex; i++) {
      TemporalFilter_tonic[k].h[i] = 0.0;
    }
  }

  //----------------------------------------------[ SpontaneousActivity ]-----
  //->SpontaneousActivity = 10.0;
}

//----------------------------------------------------------------------------
//
//  MAIN PROGRAM
//
//----------------------------------------------------------------------------

void calculateXCellResponse() {
  int i, index;
  double t;

  //
  // apply spatial filter
  //
  for (t=Simulation.tstart; t<Simulation.tend; t+=Simulation.dt) {
    index = (int)((t+SMALL)/(Simulation.dt))+1;

    // change stimulus contrast
    if ((t>Stimulus_start) && (t<Stimulus_end)) {
      if (Stimulus == CSPOT_STIMULUS) Stimulus_cspot.I[index] = 1.0;
      else if (Stimulus == BAR_STIMULUS) Stimulus_bar.I[index] = 1.0;
    }
    else {
      if (Stimulus == CSPOT_STIMULUS) Stimulus_cspot.I[index] = 0.0;
      else if (Stimulus == BAR_STIMULUS) Stimulus_bar.I[index] = 0.0;
    }

    // apply spatial filters
    if (Stimulus == CSPOT_STIMULUS) {
      for (i=1; i<=8; i++) applySpatialFilter_cspot(index, &Stimulus_cspot, &SpatialFilter[i], &A[i]);
    }
    else if (Stimulus == BAR_STIMULUS) {
      for (i=1; i<=8; i++) applySpatialFilter_bar(index, &Stimulus_bar, &SpatialFilter[i], &A[i]);
    }
  }

  //
  // apply temporal filters
  //
  applyTemporalFilter_phasic(&Simulation, &A[1], &TemporalFilter_phasic[1], &B[1]);
  applyTemporalFilter_phasic(&Simulation, &A[2], &TemporalFilter_phasic[2], &B[2]);
  applyTemporalFilter_tonic(&Simulation, &A[3], &TemporalFilter_tonic[1], &B[3]);
  applyTemporalFilter_tonic(&Simulation, &A[4], &TemporalFilter_tonic[2], &B[4]);
  applyTemporalFilter_phasic(&Simulation, &A[5], &TemporalFilter_phasic[3], &B[5]);
  applyTemporalFilter_phasic(&Simulation, &A[6], &TemporalFilter_phasic[4], &B[6]);
  applyTemporalFilter_tonic(&Simulation, &A[7], &TemporalFilter_tonic[3], &B[7]);
  applyTemporalFilter_tonic(&Simulation, &A[8], &TemporalFilter_tonic[4], &B[8]);

  for (t=Simulation.tstart; t<Simulation.tend; t+=Simulation.dt) {

    index = (int)((t+SMALL)/(Simulation.dt))+1;
    //
    // apply nonlinear stage
    //
    applyNonlinearStage_type1(index, &B[1], &C[1]);
    applyNonlinearStage_type2(index, &B[2], &C[2]);
    applyNonlinearStage_type1(index, &B[3], &C[3]);
    applyNonlinearStage_type2(index, &B[4], &C[4]);
    applyNonlinearStage_type3(index, &B[5], &C[5]);
    applyNonlinearStage_type4(index, &B[6], &C[6]);
    applyNonlinearStage_type3(index, &B[7], &C[7]);
    applyNonlinearStage_type4(index, &B[8], &C[8]);

    //
    // summation, adding of spontaneous activity, global rectification
    //
    FreqOut.out[index] = 0.0;
    for (i=1; i<=8; i++) FreqOut.out[index] += C[i].out[index];
    FreqOut.out[index] += SpontaneousActivity;
    (FreqOut.out[index] < 0.0) ? FreqOut.out[index] = 0.0 : FreqOut.out[index];

    //
    // mapping time scale t -> tau
    // get switches for switching GRP
    //
    SwitchingGRP.t_tau[index] = SwitchingGRP.t_tau[index-1] + (Simulation.dt)*FreqOut.out[index];
    if ((FreqOut.out[index] >= SwitchingGRP.Threshold) && (FreqOut.out[index-1] < SwitchingGRP.Threshold)) {
      SwitchingGRP.Switches[SwitchingGRP.NumberSwitches] = SwitchingGRP.t_tau[index];
      SwitchingGRP.NumberSwitches++;
    }
    else if ((FreqOut.out[index] <= SwitchingGRP.Threshold) && (FreqOut.out[index-1] > SwitchingGRP.Threshold)) {
      SwitchingGRP.Switches[SwitchingGRP.NumberSwitches] = SwitchingGRP.t_tau[index];
      SwitchingGRP.NumberSwitches++;
    }
  }

  //
  // switching GRP
  //
  applySwitchingGRP(&Simulation, &SwitchingGRP, &SpikeOut);
}
