//============================================================================
//
//  function library for phenomenological model of visually
//  evoked spike trains in cat geniculate nonlagged X-cells
//
//  include file
//
//============================================================================


//
// definition of general simulation parameters
//

struct sSimulation {
  double tstart;
  double tend;
  double dt;
  int maxindex;
  int seed;
  float Vrest;
  float Vspike;
};


//
// definition of visual stimuli
//

struct sVisualStimulus_bar {
  float a;      // dimension
  float b;      // dimension
  float x0;     // x coordinate
  float y0;     // y coordinate
  float theta;  // angle with x-axis
  float *I;     // stimulus contrast (function of time)
};

struct sVisualStimulus_cspot {
  float D;      // diameter
  float *I;     // stimulus contrast (function of time)
};


//
// definition of inout/output vectors of different filters/stages
//

struct sStageOut {
  float *out;
  double tres;
};


//
// definition of spatial filter parameters
//

struct sSpatialFilter {
  float sigma;          // [deg]
};


//
// definition of temporal filters
//

struct sTemporalFilter_phasic {
  float A;
  float tau1;           // [ms]
  float tau2;           // [ms]
  float *h;
  double tres;
};

struct sTemporalFilter_tonic {
  float B;
  float tau;            // [ms]
  float *h;
  double tres;

};


//
// definition of structure used for switching gamma renewal process
//

struct sSwitchingGRP {
  float Threshold;
  int OrderGRP[3];
  double *t_tau;
  double Switches[100];
  int NumberSwitches;
  int maxIndex_t_tau;
  double tres;
};


//
// declaration of functions
//

float erff(float x);
float gammln(float xx);
float gammp(float a, float x);
void gcf(float *gammcf, float a, float x, float *gln);
void gser(float *gamser, float a, float x, float *gln);
void convlv(float data[], unsigned long n, float respns[], unsigned long m, int isign, float ans[]);
void realft(float data[], unsigned long n, int isign);
void twofft(float data1[], float data2[], float fft1[], float fft2[], unsigned long n);
void four1(float data[], unsigned long nn, int isign);
float gamdev(int ia, long *idum);
float gamdevTilde(int ia, long *idum);
float ran1(long *idum);

void applySpatialFilter_bar(int index, struct sVisualStimulus_bar *stimulus, struct sSpatialFilter *filter, struct sStageOut *output);
void applySpatialFilter_cspot(int index, struct sVisualStimulus_cspot *stimulus, struct sSpatialFilter *filter, struct sStageOut *output);
void applyTemporalFilter_phasic(struct sSimulation *sim, struct sStageOut *input, struct sTemporalFilter_phasic *filter, struct sStageOut *output);
void applyTemporalFilter_tonic(struct sSimulation *sim, struct sStageOut *input, struct sTemporalFilter_tonic *filter, struct sStageOut *output);
void applyNonlinearStage_type1(int index, struct sStageOut *input, struct sStageOut *output);
void applyNonlinearStage_type2(int index, struct sStageOut *input, struct sStageOut *output);
void applyNonlinearStage_type3(int index, struct sStageOut *input, struct sStageOut *output);
void applyNonlinearStage_type4(int index, struct sStageOut *input, struct sStageOut *output);
void applySwitchingGRP(struct sSimulation *sim, struct sSwitchingGRP *sgrp, struct sStageOut *output);
