//==============================================================================
//
//      simulation of phenomenological model of visually
//      evoked spike trains in cat geniculate nonlagged X-cells
//
//      for further information and references see main.hoc
//
//==============================================================================

//------------------------------------------------------------------------------
//  general settings
//------------------------------------------------------------------------------
ENABLE_GRAPHICAL_INTERFACE = 1
ENABLE_AUTORUN = 0
ENABLE_AUTOEXIT = 0

//------------------------------------------------------------------------------
//  general simulation parameter
//------------------------------------------------------------------------------
DT = 0.1                        // (ms)
TSTART = 0                      // (ms)
TSTOP = 1500                    // (ms)
TEMPERATURE = 36                // (degC)
V_INIT = -70                    // (mV)
V_REST = V_INIT                 // (mV)
V_SPIKE = 20                    // (mV)

//------------------------------------------------------------------------------
//  spatial filter parameters
//------------------------------------------------------------------------------
SPATIAL_FILTER_1_SIGMA = 0.11   // (deg)
SPATIAL_FILTER_2_SIGMA = 0.33   // (deg)
SPATIAL_FILTER_3_SIGMA = 0.11   // (deg)
SPATIAL_FILTER_4_SIGMA = 0.33   // (deg)
SPATIAL_FILTER_5_SIGMA = 0.11   // (deg)
SPATIAL_FILTER_6_SIGMA = 0.33   // (deg)
SPATIAL_FILTER_7_SIGMA = 0.11   // (deg)
SPATIAL_FILTER_8_SIGMA = 0.33   // (deg)

//------------------------------------------------------------------------------
//  temporal filter parameters
//------------------------------------------------------------------------------
TEMPORAL_FILTER_1_A    = 3370.0
TEMPORAL_FILTER_1_TAU1 = 13.0   // (ms)
TEMPORAL_FILTER_1_TAU2 = 15.0   // (ms)
TEMPORAL_FILTER_2_A    = 3370.0
TEMPORAL_FILTER_2_TAU1 = 13.0   // (ms)
TEMPORAL_FILTER_2_TAU2 = 15.0   // (ms)
TEMPORAL_FILTER_3_B    = 74.0
TEMPORAL_FILTER_3_TAU  = 15.0   // (ms)
TEMPORAL_FILTER_4_B    = 74.0
TEMPORAL_FILTER_4_TAU  = 15.0   // (ms)
TEMPORAL_FILTER_5_A    = 1900.0
TEMPORAL_FILTER_5_TAU1 = 13.0   // (ms)
TEMPORAL_FILTER_5_TAU2 = 15.0   // (ms)
TEMPORAL_FILTER_6_A    = 1900.0
TEMPORAL_FILTER_6_TAU1 = 13.0   // (ms)
TEMPORAL_FILTER_6_TAU2 = 15.0   // (ms)
TEMPORAL_FILTER_7_B    = 33.0
TEMPORAL_FILTER_7_TAU  = 15.0   // (ms)
TEMPORAL_FILTER_8_B    = 33.0
TEMPORAL_FILTER_8_TAU  = 15.0   // (ms)

//------------------------------------------------------------------------------
//  spontaneous activity
//------------------------------------------------------------------------------
BACKGROUND = 10.0               // (Hz)

//------------------------------------------------------------------------------
//  stimulation parameters
//------------------------------------------------------------------------------
CSPOT_STIMULUS  = 1             // see XCellModel.c
BAR_STIMULUS    = 2
STIMULUS        = CSPOT_STIMULUS
STIMULUS_START  = 200           // (ms)
STIMULUS_END    = 600           // (ms)
CSPOT_STIMULUS_D   = 0.5        // (deg)
BAR_STIMULUS_A     = 0.5        // (deg)
BAR_STIMULUS_B     = 2.0        // (deg)
BAR_STIMULUS_X0    = 0.0        // (deg)
BAR_STIMULUS_Y0    = 0.5        // (deg)
BAR_STIMULUS_THETA = 180        // (deg)

//------------------------------------------------------------------------------
//  switching GRP
//------------------------------------------------------------------------------
SGRP_THRESHOLD     = 65.0    // (Hz)
SGRP_ORDER_BELOW   = 1
SGRP_ORDER_ABOVE   = 5

//==============================================================================
