//==============================================================================
//
//      simulation of one-compartment model with individual 
//      synaptic inputs (exponential synapses)
//
//      for further information and references see main.hoc
//
//==============================================================================

//------------------------------------------------------------------------------
// general settings
//------------------------------------------------------------------------------
ENABLE_GRAPHICAL_INTERFACE = 1
ENABLE_AUTORUN = 0
ENABLE_AUTOEXIT = 0

//------------------------------------------------------------------------------
//  general simulation parameter
//------------------------------------------------------------------------------
DT = 0.1                        // (ms)
TSTART = 0                      // (ms)
TSTOP = 1000                 	// (ms)
TEMPERATURE = 36                // (degC)
V_INIT = -80                    // (mV)

//------------------------------------------------------------------------------
//  passive cell properties [1]
//------------------------------------------------------------------------------
EPAS = -80                      // (mV)

// -[ soma ]-
GPAS_SOMA       = 4.52e-5       // (S/cm^2)
CM_SOMA         = 1             // (uF/cm^2)
RA_SOMA         = 250           // (ohm cm)

//------------------------------------------------------------------------------
//  synaptic background activity
//------------------------------------------------------------------------------
ENABLE_BACKGROUND = 1

// -[ ExpSyn ]-
G_EXPSYN_SOMA = 0.001           // (uS)
TAU_EXPSYN = 20          	// (ms)
DEADTIME_EXPSYN = 1.0           // (ms)
PTHRESHOLD_EXPSYN = 0           // (mV)
EREV_EXPSYN = 0                 // (mV)

// synaptic background settings 
RNDSEED_EXPSYN = -19		// random seed for DGA 

FREQ_EXPSYN_SOMA = 10		// (Hz)
PRESYN_REFRACT = 0.0		// (ms) presynaptic refractory period

//------------------------------------------------------------------------------
//  stimulation settings
//------------------------------------------------------------------------------

// -[ iStimConst ]-
STIM_ICLAMP_DEL = 0           	// (ms)
STIM_ICLAMP_DUR = 10000000 	// (ms)
STIM_ICLAMP_AMP = 0.0     	// (nA)

//------------------------------------------------------------------------------
//  recording
//------------------------------------------------------------------------------
strdef REC_VM_FILENAME
REC_VM_FILENAME = "Vm.rec"

strdef REC_EXPSYN_CONDUCTANCE_FILENAME
REC_EXPSYN_CONDUCTANCE_FILENAME = "gExpSyn.rec"

//==============================================================================
