//==============================================================================
//
//      simulation of fluctuating conductance model of background activity
//      [simulation parameters and settings]
//
//      for further information and references see main.hoc
//
//==============================================================================

//------------------------------------------------------------------------------
// general settings
//------------------------------------------------------------------------------
ENABLE_GRAPHICAL_INTERFACE = 1
ENABLE_AUTORUN = 0
ENABLE_AUTOEXIT = 0

//------------------------------------------------------------------------------
//  general simulation parameter
//------------------------------------------------------------------------------
DT = 0.1                        // (ms)
TSTART = 0                      // (ms)
TSTOP = 10000                   // (ms)
TEMPERATURE = 36                // (degC)
V_INIT = -70                    // (mV)

//------------------------------------------------------------------------------
//  passive cell properties [2]
//------------------------------------------------------------------------------
EPAS = -80                      // (mV)

// -[ soma ]-
GPAS_SOMA       = 4.52e-5       // (S/cm^2)
CM_SOMA         = 1             // (uF/cm^2)
RA_SOMA         = 250           // (ohm cm)

//------------------------------------------------------------------------------
//  active cell properties [2]
//------------------------------------------------------------------------------
JOHNSTON_CORRECTION = 4.3
ENA = 50                        // (mV)
EK = -90                        // (mV)

// -[ INa ]-
INA_SHIFT_A = 58                // (mV)
INA_SHIFT_I = 68                // (mV)
INA_GNABAR_SOMA = 1.6*JOHNSTON_CORRECTION*120e-4    // (S/cm^2)

// -[ IKd ]-
IKD_SHIFT = 58                  // (mV)
IKD_GKBAR_SOMA = 1.6*100e-4         // (S/cm^2)

// -[ IKm ]-
IKM_GKBAR_SOMA = 0*5e-4           // (S/cm^2)

//------------------------------------------------------------------------------
//  synaptic background activity (ggSBA point process)
//------------------------------------------------------------------------------
GGSBA_SEED = -122134

GGSBA_EE = 0           // (mV)
GGSBA_EI = -75         // (mV)

GGSBA_GE0 = 0.0121     // (uS)
GGSBA_GI0 = 0.0573     // (uS)

GGSBA_STDE = 1*0.012     // (uS)
GGSBA_STDI = 1*0.0264    // (uS)

GGSBA_TAUE = 2.728     // (ms)
GGSBA_TAUI = 10.49     // (ms)

//------------------------------------------------------------------------------
//  recording
//------------------------------------------------------------------------------
strdef REC_VM_FILENAME
REC_VM_FILENAME = "Vm.rec"

strdef REC_SPIKES_FILENAME
REC_SPIKES_FILENAME = "spikes.rec"

//------------------------------------------------------------------------------
