://=============================================================================
://  StimTrigger1  -  presynaptic stimulating trigger (v1.0)
://=============================================================================
://
://  REMARKS: - simple mechanism to trigger mulitple presynaptic signals at
://             multiple times given by the user.
://           - N (which should be the max number of synapses) synapses
://             are stimulated
://
://  IMPLEMENTATION: Nicolas Ho, Laval University, 1998
://
://  MODIFICATION: Michael Rudolph, UNIC/CNRS Paris, April 2001
://
://=============================================================================

INDEPENDENT {t FROM 0 TO 1 WITH 1 (ms)}

DEFINE MAXTRIG 2000

NEURON {
  POINT_PROCESS StimTrigger1
  RANGE x, min_val, max_val
  RANGE stim_start, stim_dt
}

PARAMETER {
  dt              (ms)
  tstim           = 0
  stim            = 0
  min_val         = -70           :// min value of presynaptic variable
  max_val         = 40            :// max value of presynaptic variable
  stim_start      = 5 (ms)        :// start additional stimulation
  stim_dt         = 5 (ms)        :// timestep for subsequent stimulations in [ms]
}

ASSIGNED {
  x[MAXTRIG]
  index
}

INITIAL {
  index = 0
  FROM i=0 TO MAXTRIG-1 { x[i] = min_val }
}

BREAKPOINT {
  SOLVE generate
}

UNITSOFF

PROCEDURE generate() {
  tstim = stim_start + stim_dt*index
  if( (t>=tstim-dt/2) && (t<=(tstim+dt/2)) && (stim == 0)) { LOCAL i, j
    FROM i=0 TO MAXTRIG-1 { x[i] = max_val }
    stim = 1
    index = index + 1
  } else if (stim == 1) {
    FROM i=0 TO MAXTRIG-1 { x[i] = min_val }
    stim = 0
  }
}

UNITSON

://=============================================================================
