//==============================================================================
//
//      simulation of a cortical layer 6 pyramidal neuron
//      [simulation parameters and settings]
//
//      for further information and references see main.hoc
//
//==============================================================================

//------------------------------------------------------------------------------
// general settings
//------------------------------------------------------------------------------
ENABLE_GRAPHICAL_INTERFACE = 1
ENABLE_AUTORUN = 0
ENABLE_AUTOEXIT = 0

//------------------------------------------------------------------------------
//  general simulation parameter
//------------------------------------------------------------------------------
DT = 0.1                        // (ms)
TSTART = 0                      // (ms)
TSTOP = 1000                  // (ms)
TEMPERATURE = 36                // (degC)
V_INIT = -65                    // (mV)

//------------------------------------------------------------------------------
//  morphological parameter [3]
//------------------------------------------------------------------------------
SPINES_CORRECTION = 1.449

//------------------------------------------------------------------------------
//  passive cell properties [2,3,4]
//------------------------------------------------------------------------------
EPAS = -80                      // (mV)

// -[ axon ]-[2,4]
GPAS_AXON_ISEG   = 4.52e-5      // (S/cm^2)
GPAS_AXON_HILL   = 4.52e-5      // (S/cm^2)
GPAS_AXON_MYELIN = 4.52e-5      // (S/cm^2)
GPAS_AXON_NODE   = 0.02         // (S/cm^2)
CM_AXON_ISEG     = 1.00         // (uF/cm^2)
CM_AXON_HILL     = 1.00         // (uF/cm^2)
CM_AXON_MYELIN   = 0.04         // (uF/cm^2)
CM_AXON_NODE     = 1.00         // (uF/cm^2)
RA_AXON_ISEG     = 250          // (ohm cm)
RA_AXON_HILL     = 250          // (ohm cm)
RA_AXON_MYELIN   = 250          // (ohm cm)
RA_AXON_NODE     = 250          // (ohm cm)

// -[ soma ]-[4]
GPAS_SOMA        = 4.52e-5      // (S/cm^2)
CM_SOMA          = 1.00         // (uF/cm^2)
RA_SOMA          = 250          // (ohm cm)

// -[ dend ]-[3,4]
GPAS_DEND = SPINES_CORRECTION*4.52e-5    // (S/cm^2)
CM_DEND   = SPINES_CORRECTION*1.00       // (uF/cm^2)
RA_DEND   = 250                          // (ohm cm)

//------------------------------------------------------------------------------
//  active cell properties [5,6,9]
//------------------------------------------------------------------------------
ENA = 50                          // (mV)
EK = -90                          // (mV)

// -[ INa ]-[5,6]
JOHNSTON_CORRECTION = 4.3
INA_SHIFT_A = 58                  // (mV)
INA_SHIFT_I = 68                  // (mV)
INA_GNABAR_AXON_ISEG = 1.4*JOHNSTON_CORRECTION*84e-3      	// (S/cm^2)
INA_GNABAR_AXON_HILL = 1.4*JOHNSTON_CORRECTION*84e-3      	// (S/cm^2)
INA_GNABAR_AXON_MYELIN = 1.4*JOHNSTON_CORRECTION*8.4e-3   	// (S/cm^2)
INA_GNABAR_AXON_NODE = 1.4*JOHNSTON_CORRECTION*84e-3      	// (S/cm^2)
INA_GNABAR_SOMA = 1.4*JOHNSTON_CORRECTION*8.4e-3          	// (S/cm^2)
INA_GNABAR_DEND = 1.4*SPINES_CORRECTION*JOHNSTON_CORRECTION*8.4e-3// (S/cm^2)

// -[ IKd ]-[6,9]
IKD_SHIFT = 58                  		// (mV)
IKD_GKBAR_AXON_ISEG = 1.4*70e-3   		// (S/cm^2)
IKD_GKBAR_AXON_HILL = 1.4*70e-3   		// (S/cm^2)
IKD_GKBAR_AXON_MYELIN = 1.4*7.0e-3  		// (S/cm^2)
IKD_GKBAR_AXON_NODE = 1.4*70e-3   		// (S/cm^2)
IKD_GKBAR_SOMA = 1.4*7.0e-3         		// (S/cm^2)
IKD_GKBAR_DEND = 1.4*SPINES_CORRECTION*7.0e-3     // (S/cm^2)

IKM_GKBAR_SOMA = 1.4*3.5e-4			// (S/cm^2)
IKM_GKBAR_DEND = 1.4*SPINES_CORRECTION*3.5e-4	// (S/cm^2)

//------------------------------------------------------------------------------
//  synaptic properties [10,11,12]
//------------------------------------------------------------------------------
ENABLE_BACKGROUND = 1
CUTOFF = 40                     // (um) extension of proximal dendritic region

// unit membrane areas
EX_DEND_UNIT = 1.7     			// (um) leads to 16563 synapses
IN_DEND_UNIT = 10    			// (um) leads to 2818 synapses
IN_PROX_UNIT = 10       		// (um) leads to 558 synapses
IN_SOMA_UNIT = 2.5      		// (um)

// -[ multi GABAa ]-[10,11,12]
ALPHA_MULTI_GABAA = 5           	// (1/(ms mM))
BETA_MULTI_GABAA = 0.1          	// (1/ms)
CMAX_MULTI_GABAA = 1            	// (mM)
CDUR_MULTI_GABAA = 1            	// (ms)
EREV_MULTI_GABAA = -75          	// (mV)
G_GABA_DIST = SPINES_CORRECTION*0.0006 	// (uS)
G_GABA_PROX = 0.0006            	// (uS)

// -[ multi AMPA ]-[10,11,12]
ALPHA_MULTI_AMPA = 1.1          	// (1/(ms mM))
BETA_MULTI_AMPA = 0.67          	// (1/ms)
CMAX_MULTI_AMPA = 1             	// (mM)
CDUR_MULTI_AMPA = 1             	// (ms)
EREV_MULTI_AMPA = 0             	// (mV)
G_AMPA_DIST = SPINES_CORRECTION*0.0012 	// [uS]

// synaptic background settings
strdef PROX_GABA_INPUT_FILENAME
PROX_GABA_INPUT_FILENAME = "proxGABA.RNG1"
strdef DEND_GABA_INPUT_FILENAME
DEND_GABA_INPUT_FILENAME = "dendGABA.RNG1"
strdef DEND_AMPA_INPUT_FILENAME
DEND_AMPA_INPUT_FILENAME = "dendAMPA.RNG1"

//------------------------------------------------------------------------------
//  stimulation
//------------------------------------------------------------------------------

// -[ IClamp ]-
strdef STIM_ICLAMP_SITE_NAME
STIM_ICLAMP_SITE_NAME = "soma"
STIM_ICLAMP_SITE_X = 0.5
STIM_ICLAMP_T0 = 200000000    		// [ms]
STIM_ICLAMP_DUR = 20000000      // [ms]
STIM_ICLAMP_AMP = 0.0             // [nA]

// -[ minimalAMPA ]-[7,8]
strdef STIM_AMPA_SITE_NAME
STIM_AMPA_SITE_NAME = "dend1[5]"
STIM_AMPA_SITE_X = 0.5
STIM_AMPA_T0 = 500000000          // [ms]
STIM_AMPA_DT = 500000000          // [ms]
STIM_FACTOR = 0			// # of synapses
STIM_AMPA_GMAX = STIM_FACTOR*SPINES_CORRECTION*0.0012	// [uS]

//------------------------------------------------------------------------------
//  recording
//------------------------------------------------------------------------------

// -[ voltage recording ]-
strdef REC_VM_SITE1_FILENAME
strdef REC_VM_SITE1_NAME
REC_VM_SITE1_FILENAME = "Vm.rec"
REC_VM_SITE1_NAME = "soma"
REC_VM_SITE1_X = 0.5

//==============================================================================
